@@ -35,13 +35,13 @@ class RFXmlFormatter(FormatterBase):
         try:
             data = document.sourceText
             encoding = document.properties.get('encoding', "UTF-8") if document.properties else "UTF-8"
-            parser = ET.XMLParser(encoding="utf-8")
+            # parser = ET.XMLParser(encoding="utf-8")
             if document.sourceText and document.boundaries:
                 if data.lower().startswith("<?xml"):
                     decl, data = data.split("?>", maxsplit=1)
                     decl += "?>"
-                root: ET.Element = ET.fromstring(data, parser=parser)
-                # root: ET.Element = ET.fromstring(data)
+                # root: ET.Element = ET.fromstring(data, parser=parser)
+                root: ET.Element = ET.fromstring(data)
                 baseNs = root.nsmap.get(None, None)
                 # Ignore all namespaces
                 for el in root.iter():
@@ -112,8 +112,8 @@ class RFXmlFormatter(FormatterBase):
                             descripteurs.append(descripteur)
                         thesaurus.append(descripteurs)
 
-                # data = ET.tostring(root, pretty_print=True, encoding=encoding, xml_declaration=True)
-                data = ET.tostring(root, encoding=encoding, xml_declaration=True)
+                data = ET.tostring(root, pretty_print=True, encoding=encoding, xml_declaration=True)
+                # data = ET.tostring(root, encoding=encoding, xml_declaration=True)
             filename = "file.xml"
             if document.properties and "fileName" in document.properties:
                 filepath = Path(document.properties['fileName'])
